package de.bsvrz.puk.param.param.util;

import java.util.ArrayList;
import java.util.LinkedHashMap;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Map;
import java.util.Set;

import de.bsvrz.dav.daf.main.ClientDavInterface;
import de.bsvrz.dav.daf.main.config.AttributeGroup;
import de.bsvrz.dav.daf.main.config.DynamicObjectType;
import de.bsvrz.dav.daf.main.config.SystemObject;
import de.bsvrz.dav.daf.main.config.SystemObjectType;
import de.bsvrz.puk.param.lib.MethodenBibliothek;
import de.bsvrz.puk.param.lib.Parameter;
import de.bsvrz.puk.param.lib.ParameterInfo;
import de.bsvrz.puk.param.lib.ParameterManager;
import de.bsvrz.puk.param.lib.QuellTyp;
import de.bsvrz.sys.funclib.application.StandardApplication;
import de.bsvrz.sys.funclib.application.StandardApplicationRunner;
import de.bsvrz.sys.funclib.commandLineArgs.ArgumentList;

public class ParameterLister implements StandardApplication {

	@Override
	public void parseArguments(final ArgumentList argumentList) throws Exception {
		// TODO Auto-generated method stub

	}

	@Override
	public void initialize(final ClientDavInterface connection) throws Exception {

		final ParameterManager parameterManager = MethodenBibliothek.getParameterManager(connection);
		final List<SystemObject> types = connection.getDataModel().getTypeTypeObject().getElements();
		final Map<SystemObject, Set<AttributeGroup>> checked = new LinkedHashMap<>();

		for (final SystemObject typesObj : types) {
			boolean typePrinted = false;
			final SystemObjectType type = (SystemObjectType) typesObj;
			if (type instanceof DynamicObjectType) {
				continue;
			}
			for (final AttributeGroup atg : type.getAttributeGroups()) {
				boolean print = false;
				if (atg.isParameter()) {
					final List<ParameterInfo> infos = new ArrayList<>();
					for (final SystemObject element : type.getElements()) {
						Set<AttributeGroup> atgSet = checked.get(element);
						if (atgSet == null || !atgSet.contains(atg)) {
							infos.add(new ParameterInfo(element, atg));
							if (atgSet == null) {
								atgSet = new LinkedHashSet<>();
								checked.put(element, atgSet);
							}
							atgSet.add(atg);
						}
					}
					if (!infos.isEmpty()) {
						final Parameter[] parameterOhneDaten = parameterManager
								.getParameterOhneDaten(infos.toArray(new ParameterInfo[infos.size()]));
						for (final Parameter parameter : parameterOhneDaten) {
							if (parameter.getQuelle().getTyp() == QuellTyp.DEFAULT_TYP) {
								continue;
							}
							print = true;
						}
						if (print) {
							if (!typePrinted) {
								System.err.println("Type: " + type);
								typePrinted = true;
							}
							System.err.println("\t" + atg);
						}
					}
				}
			}

		}

		System.exit(0);
	}

	public static void main(final String[] args) {
		StandardApplicationRunner.run(new ParameterLister(), args);
	}
}
